.. _dhlab.subpackages:

Sub-packages
~~~~~~~~~~~~~

.. currentmodule:: dhlab


.. autosummary::
   :recursive:
   :nosignatures:
   :toctree: generated

   api
   ngram
   text
   wordbank.wordbank
   metadata
   images.nbpictures
   visualize
